TerminateSessionFluentBuilder

Struct TerminateSessionFluentBuilder 

pub struct TerminateSessionFluentBuilder { /* private fields */ }
Fluent builder constructing a request to TerminateSession.

Terminates an active session. A TerminateSession call on a session that is already inactive (for example, in a FAILED, TERMINATED or TERMINATING state) succeeds but has no effect. Calculations running in the session when TerminateSession is called are forcefully stopped, but may display as FAILED instead of STOPPED.

Implementations

Source

impl TerminateSessionFluentBuilder

pub fn as_input(&self) -> &TerminateSessionInputBuilder

Access the TerminateSession as a reference.

pub async fn send( self, ) -> Result<TerminateSessionOutput, SdkError<TerminateSessionError, HttpResponse>>

Sends the request and returns the response.

If an error occurs, an SdkError will be returned with additional details that can be matched against.

By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.

pub fn customize( self, ) -> CustomizableOperation<TerminateSessionOutput, TerminateSessionError, Self>

Consumes this builder, creating a customizable operation that can be modified before being sent.

pub fn session_id(self, input: impl Into<String>) -> Self

The session ID.

pub fn set_session_id(self, input: Option<String>) -> Self

The session ID.

pub fn get_session_id(&self) -> &Option<String>

The session ID.